@@ -538,9 +538,9 @@ public abstract class Toolkit {
      * applets or the system.
      */
     public final EventQueue getSystemEventQueue() {
-        SecurityManager security = System.getSecurityManager();
+        SecurityManager security = glue.java.lang.System.getSecurityManager();
         if (security != null) {
-            security.checkAwtEventQueueAccess();
+        	impl.java.lang.SecurityManager.checkAwtEventQueueAccess(security);
         }
         return getSystemEventQueueImpl();
     }
@@ -597,7 +597,7 @@ public abstract class Toolkit {
         if (localL == null) {
             return;
         }
-        SecurityManager security = System.getSecurityManager();
+        SecurityManager security = glue.java.lang.System.getSecurityManager();
         if (security != null) {
             if (listenToAllAWTEventsPermission == null) {
                 listenToAllAWTEventsPermission = new AWTPermission("listenToAllAWTEvents");
@@ -650,7 +650,7 @@ public abstract class Toolkit {
         if (listener == null) {
             return;
         }
-        SecurityManager security = System.getSecurityManager();
+        SecurityManager security = glue.java.lang.System.getSecurityManager();
         if (security != null) {
             if (listenToAllAWTEventsPermission == null) {
                 listenToAllAWTEventsPermission = new AWTPermission("listenToAllAWTEvents");
