@@ -182,7 +182,7 @@ abstract public class HttpURLConnection extends URLConnection {
      * @see #getFollowRedirects()
      */
     public static void setFollowRedirects(boolean set) {
-        SecurityManager sec = System.getSecurityManager();
+        SecurityManager sec = glue.java.lang.System.getSecurityManager();
         if (sec != null) {
             // seems to be the best check here...
             sec.checkSetFactory();
@@ -266,7 +266,7 @@ abstract public class HttpURLConnection extends URLConnection {
         for (int i = 0; i < methods.length; i++) {
             if (methods[i].equals(method)) {
                 if (method.equals("TRACE")) {
-                    SecurityManager s = System.getSecurityManager();
+                    SecurityManager s = glue.java.lang.System.getSecurityManager();
                     if (s != null) {
                         s.checkPermission(new NetPermission("allowHttpTrace"));
                     }
